pub enum S3SnapshotError {
BucketDisappeared {
bucket: String,
},
ReadObject {
bucket: String,
key: String,
version_id: String,
source: Box<S3ServiceError>,
},
ReadPart {
bucket: String,
upload_id: String,
part_number: u32,
source: Box<S3ServiceError>,
},
WriteObject {
bucket: String,
key: String,
version_id: String,
source: Box<S3ServiceError>,
},
WritePart {
bucket: String,
upload_id: String,
part_number: u32,
source: Box<S3ServiceError>,
},
Io {
path: String,
source: Error,
},
InvalidDataPath {
path: String,
},
}Expand description
Errors raised while exporting or importing S3 snapshots.
Variants
BucketDisappeared
Bucket referenced in the bucket list disappeared during export.
ReadObject
Object data could not be read through the storage backend.
Fields

source: Box<S3ServiceError>Source error.
ReadPart
Multipart part data could not be read through the storage backend.
Fields

source: Box<S3ServiceError>Source error.
WriteObject
Object data could not be written through the storage backend.
Fields

source: Box<S3ServiceError>Source error.
WritePart
Multipart part data could not be written through the storage backend.
Fields

source: Box<S3ServiceError>Source error.
Io
File-system I/O failed.
InvalidDataPath
Snapshot metadata referenced a data path outside its data directory.