pub enum Permission {
FullControl,
Read,
Write,
ReadAcp,
WriteAcp,
}Expand description
A permission that can be granted to a grantee.
Variants
FullControl
Grants full control (READ, WRITE, READ_ACP, WRITE_ACP).
Read
Allows grantee to list objects in the bucket or read the object data.
Write
Allows grantee to create objects in the bucket.
ReadAcp
Allows grantee to read the bucket/object ACL.
WriteAcp
Allows grantee to write the bucket/object ACL.