CorsRuleConfig

Struct CorsRuleConfig 

pub struct CorsRuleConfig {
    pub id: Option<String>,
    pub allowed_origins: Vec<String>,
    pub allowed_methods: Vec<String>,
    pub allowed_headers: Vec<String>,
    pub expose_headers: Vec<String>,
    pub max_age_seconds: Option<i32>,
}
CORS rule configuration stored on a bucket.

This is the raw configuration value, not the evaluated CORS rule used at request time (see cors.rs for the runtime representation).

Fields

id: Option<String>

Optional identifier for the rule.

allowed_origins: Vec<String>

Origins that are allowed to make cross-domain requests.

allowed_methods: Vec<String>

HTTP methods that the origin is allowed to execute.

allowed_headers: Vec<String>

Headers that are allowed in a pre-flight OPTIONS request.

expose_headers: Vec<String>

Headers in the response that customers are able to access.

max_age_seconds: Option<i32>

Time in seconds that the browser should cache the preflight response.