Validation for S3 requests.
Provides validation functions for bucket names, object keys, tags, and user-defined metadata following the rules defined in the Amazon S3 documentation.
Functions
- validate_
bucket_ name - Validate an S3 bucket name.
- validate_
content_ md5 - Validate the
Content-MD5header against the request body. - validate_
metadata - Validate user-defined metadata.
- validate_
object_ key - Validate an S3 object key.
- validate_
tag_ key - Validate a tag key.
- validate_
tag_ value - Validate a tag value.
- validate_
tags - Validate a set of tags.