pub enum S3ServiceError {
Show 40 variants
NoSuchBucket {
bucket: String,
},
BucketAlreadyExists {
bucket: String,
},
BucketAlreadyOwnedByYou {
bucket: String,
},
BucketNotEmpty {
bucket: String,
},
NoSuchKey {
key: String,
},
NoSuchVersion {
key: String,
version_id: String,
},
NoSuchUpload {
upload_id: String,
},
InvalidPartOrder,
InvalidPart,
EntityTooSmall,
EntityTooLarge,
InvalidBucketName {
name: String,
reason: String,
},
InvalidArgument {
message: String,
},
InvalidRange,
InvalidTag {
message: String,
},
MalformedXml,
AccessDenied,
MethodNotAllowed,
NotImplemented,
PreconditionFailed,
ConditionalRequestConflict,
NotModified,
InvalidObjectState,
ObjectNotInActiveTierError,
InvalidDigest,
BadDigest,
MissingContentLength,
KeyTooLong,
MaxMessageLengthExceeded,
NoSuchCorsConfiguration,
NoSuchTagSet,
NoSuchLifecycleConfiguration,
NoSuchBucketPolicy,
NoSuchWebsiteConfiguration,
NoSuchPublicAccessBlockConfiguration,
ServerSideEncryptionConfigurationNotFoundError,
ObjectLockConfigurationNotFoundError,
OwnershipControlsNotFoundError,
ReplicationConfigurationNotFoundError,
Internal(Error),
}Expand description
Variants
NoSuchBucket
The specified bucket does not exist.
BucketAlreadyExists
The requested bucket name is not available (owned by another account).
BucketAlreadyOwnedByYou
The bucket already exists and is owned by you.
BucketNotEmpty
The bucket is not empty and cannot be deleted.
NoSuchKey
The specified key does not exist.
NoSuchVersion
The specified version does not exist.
NoSuchUpload
The specified multipart upload does not exist.
InvalidPartOrder
The list of parts was not in ascending order.
InvalidPart
One or more of the specified parts could not be found.
EntityTooSmall
A proposed upload part is smaller than the minimum allowed size.
EntityTooLarge
The entity body is too large.
InvalidBucketName
The specified bucket name is not valid.
InvalidArgument
An argument provided is invalid.
InvalidRange
The requested range is not satisfiable.
InvalidTag
A tag key or value is invalid.
MalformedXml
The XML body is malformed.
AccessDenied
Access denied.
MethodNotAllowed
The HTTP method is not allowed against this resource.
NotImplemented
The requested functionality is not implemented.
PreconditionFailed
A precondition specified in the request was not met.
ConditionalRequestConflict
The conditional request cannot be processed.
NotModified
The resource has not been modified (304).
InvalidObjectState
The operation is not valid for the object’s storage class.
ObjectNotInActiveTierError
The object is not in an active tier.
InvalidDigest
The Content-MD5 you specified is invalid.
BadDigest
The Content-MD5 you specified did not match what we received.
MissingContentLength
Missing Content-Length header.
KeyTooLong
The key is too long.
MaxMessageLengthExceeded
The message body exceeds the maximum length.
NoSuchCorsConfiguration
The CORS configuration does not exist.
NoSuchTagSet
The tag set does not exist.
NoSuchLifecycleConfiguration
The lifecycle configuration does not exist.
NoSuchBucketPolicy
The bucket policy does not exist.
NoSuchWebsiteConfiguration
The website configuration does not exist.
NoSuchPublicAccessBlockConfiguration
The public access block configuration does not exist.
ServerSideEncryptionConfigurationNotFoundError
The server-side encryption configuration does not exist.
ObjectLockConfigurationNotFoundError
The object lock configuration does not exist.
OwnershipControlsNotFoundError
The ownership controls configuration does not exist.
ReplicationConfigurationNotFoundError
The replication configuration does not exist.
Internal(Error)
Internal error with context.
Implementations
Sourceimpl S3ServiceError
impl S3ServiceError
Sourcepub fn into_s3_error(self) -> S3Error
pub fn into_s3_error(self) -> S3Error
Convert this error into an S3Error.
This is equivalent to S3Error::from(self) but available as a
method for convenience in chained calls.